@@ -104,7 +104,7 @@ class OrgInvestigator:
                             captcha_code = ext_apis.captcha_rec_3023data(captcha_bs64,
                                                                          format="png",
                                                                          type=5001,
-                                                                         api_key=api_key)
+                                                                         api_key=self.api_key)
                             # input captcha code
                             captcha_inp.send_keys(captcha_code)
                             # click to submit
